@@ -10,7 +10,7 @@ use Wikibase::Datatype::Print::Value;
 
 Readonly::Array our @EXPORT_OK => qw(print);
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 sub print {
 	my ($obj, $opts_hr) = @_;
@@ -36,7 +36,12 @@ sub print {
 		$ret .= 'no value';
 	} elsif ($obj->snaktype eq 'somevalue') {
 		$ret .= 'unknown value';
+	} else {
+		err 'Bad snaktype.',
+			'snaktype', $obj->snaktype,
+		;
 	}
+
 	return $ret;
 }
 
